# main.py
import machine
import socket
import time
import ujson as json
from wifi import WifiSTA
from credentials import *

## Pins
PIN_UP = 14 # D5
PIN_LE = 12 # D6
PIN_RI = 13 # D7
# PIN_DN = 16 # D0 - does not support pull
PIN_DN =  2 # D4
PIN_B1 =  0 # D2
PIN_B2 =  4 # D3
## Delay
DELAY_CMD = 0.1
## HOST
# RX_ADDR = ("192.168.11.220", 80)
# RX_ADDR = ("192.168.11.217", 8000)
RX_ADDR = ("192.168.0.1", 8000)

## Runtime
wifiSTA = None

def send_data(s, data):
    print("data: {}".format(data))
    try:
        s.sendto(data.encode(), RX_ADDR)
    except Exception as ex:
        print("Exception Type:{}, args: {}".format(type(ex).__name__, ex.args))

def main():
    global wifiSTA
    wifiSTA = WifiSTA(SSID, PASS)
    # initialize buttons
    btn_up = machine.Pin(PIN_UP, machine.Pin.IN, machine.Pin.PULL_UP)
    btn_dn = machine.Pin(PIN_DN, machine.Pin.IN, machine.Pin.PULL_UP)
    btn_le = machine.Pin(PIN_LE, machine.Pin.IN, machine.Pin.PULL_UP)
    btn_ri = machine.Pin(PIN_RI, machine.Pin.IN, machine.Pin.PULL_UP)
    btn_b1 = machine.Pin(PIN_B1, machine.Pin.IN, machine.Pin.PULL_UP)
    btn_b2 = machine.Pin(PIN_B2, machine.Pin.IN, machine.Pin.PULL_UP)
    # initialize socket
    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    # runtime
    buttons = {"btn_up": btn_up, "btn_dn": btn_dn, "btn_le": btn_le,
               "btn_ri": btn_ri, "btn_b1": btn_b1, "btn_b2": btn_b2}
    values = {"btn_up": 0, "btn_dn": 0, "btn_le": 0,
              "btn_ri": 0, "btn_b1": 0, "btn_b2": 0}
    # loop
    while True:
        wifiSTA.check()

        for name, button in buttons.items():
            values[name] = not button.value()

        send_data(s, json.dumps(values))
        time.sleep(DELAY_CMD)

if __name__ == "__main__":
    main()
